import Vue from 'vue';
import ElementUI from 'element-ui';
import 'element-ui/lib/theme-chalk/index.css';
import './assets/app.css';
import App from './App.vue';
import router from './router';
import './plugins/page'
import Page from '@/components/Page'
Vue.component('Page', Page)
Vue.use(ElementUI);

new Vue({
  el: '#app',
  data:{
    userInfo:{},
    datePickerOptions:{
      shortcuts: [{
        text: '今天',
        onClick(picker) {
          picker.$emit('pick', new Date());
        }
      }, {
        text: '昨天',
        onClick(picker) {
          const date = new Date();
          date.setTime(date.getTime() - 3600 * 1000 * 24);
          picker.$emit('pick', date);
        }
      }, {
        text: '一周前',
        onClick(picker) {
          const date = new Date();
          date.setTime(date.getTime() - 3600 * 1000 * 24 * 7);
          picker.$emit('pick', date);
        }
      }]
    },
    rules: {
      string: [
        { required: true, message: '请输入', min: 1, trigger: 'blur' }
      ],
      select: [
        { required: true, message: '请选择', trigger: 'change' }
      ],
      int: [
        { type: 'number', required: true, message: '请输入', trigger: 'blur' }
      ],
      array: [
        { type: 'array', required: true, message: '请选择', trigger: 'change' }
      ],
      intRange (min, max) {
        return [
          { type: 'number', min: min, max: max, required: true, message: '请输入', trigger: 'blur' }
        ]
      },
      intMin (min) {
        return [
          { type: 'number', min: min, required: true, message: '请输入', trigger: 'blur' }
        ]
      }

    }
  },
  computed:{
    uploadUrl(){
      return `${process.env.VUE_APP_URL}/upload`
    }
  },
  router,
  render: h => h(App)
});